@@ -12,7 +12,7 @@
 #include <dune/grid/albertagrid.hh>
 #include <dune/grid/albertagrid/dgfparser.hh>
 
-#include "basicunitcube.hh"
+#include <doc/grids/gridfactory/testgrids.hh>
 
 #include "../common/boundaryprojection.hh"
 
@@ -26,6 +26,9 @@
 #include "check-albertareader.hh"
 #include "checkadaptation.hh"
 #include "checkpartition.hh"
+#include "checkgridfactory.hh"
+
+#include <doc/grids/gridfactory/testgrids.hh>
 
 
 template< int dim, int dimworld >
@@ -55,6 +58,44 @@ void markOne ( GridType & grid , int num , int ref )
   grid.postAdapt();
 }
 
+template< class Grid, int dim >
+void addToGridFactory ( Dune::GridFactory< Grid > &factory, Dune::Dim< dim > );
+
+template< class Grid >
+void addToGridFactory ( Dune::GridFactory< Grid > &factory, Dune::Dim< 1 > )
+{
+  Dune::TestGrids::unitLine.addToGridFactory( factory,
+      [] ( const typename Dune::TestGrid< 1 >::Vertex &x ) {
+        typename Dune::TestGrid< 1 >::Vertex y = x;
+        y *= 2.0; y -= typename Dune::TestGrid< 1 >::Vertex( 1.0 );
+        return y;
+        }
+      );
+}
+
+template< class Grid >
+void addToGridFactory ( Dune::GridFactory< Grid > &factory, Dune::Dim< 2 > )
+{
+  Dune::TestGrids::kuhn2d.addToGridFactory( factory,
+      [] ( const typename Dune::TestGrid< 2 >::Vertex &x ) {
+        typename Dune::TestGrid< 2 >::Vertex y = x;
+        y *= 2.0; y -= typename Dune::TestGrid< 2 >::Vertex( 1.0 );
+        return y;
+        }
+      );
+}
+
+template< class Grid >
+void addToGridFactory ( Dune::GridFactory< Grid > &factory, Dune::Dim< 3 > )
+{
+  Dune::TestGrids::kuhn3d.addToGridFactory( factory,
+      [] ( const typename Dune::TestGrid< 3 >::Vertex &x ) {
+        typename Dune::TestGrid< 3 >::Vertex y = x;
+        y *= 2.0; y -= typename Dune::TestGrid< 3 >::Vertex( 1.0 );
+        return y;
+        }
+      );
+}
 
 template< class Grid >
 void checkProjectedUnitCube ()
@@ -62,8 +103,7 @@ void checkProjectedUnitCube ()
   typedef Dune::CircleBoundaryProjection< Grid::dimensionworld > Projection;
   std::cout << ">>> Checking projected unit cube..." << std::endl;
   Dune::GridFactory< Grid > gridFactory;
-  BasicUnitCube< Grid::dimension >::insertVertices( gridFactory, -1.0, 1.0 );
-  BasicUnitCube< Grid::dimension >::insertSimplices( gridFactory );
+  addToGridFactory( gridFactory, Dune::Dim< Grid::dimensionworld > () );
   gridFactory.insertBoundaryProjection( new Projection );
   gridFactory.markLongestEdge();
   Grid *grid = gridFactory.createGrid();
@@ -84,6 +124,16 @@ try {
 
   std::cout << "Testing " << GridType::typeName() << "..." << std::endl;
 
+#if ALBERTA_DIM == 2 && GRIDDIM == 2
+  std::cout << "Check GridFactory ..." <<std::endl;
+  Dune::checkGridFactory< GridType >( Dune::TestGrids::kuhn2d );
+#endif // #if ALBERTA_DIM == 2 && GRIDDIM == 2
+
+#if ALBERTA_DIM == 3 && GRIDDIM == 3
+  std::cout << "Check GridFactory ..." <<std::endl;
+  Dune::checkGridFactory< GridType >( Dune::TestGrids::kuhn3d );
+#endif // #if ALBERTA_DIM == 3 && GRIDDIM == 3
+
   std::string filename;
   if( argc <= 1 )
   {
