@@ -6,6 +6,8 @@
 #include <dune/grid/uggrid/uggridentity.hh>
 #include <dune/grid/uggrid/uggridrenumberer.hh>
 
+namespace Dune {
+
 //*************************************************************************
 //
 //  --UGGridEntity
@@ -20,36 +22,25 @@
 //*********************************************************************
 
 
-//*****************************************************************8
-// count
-template <int codim, int dim, class GridImp>
-template <int cc>
-int Dune::UGGridEntity<codim,dim,GridImp>::count () const
-{
-  DUNE_THROW(GridError, "UGGridEntity<" << codim << ", " << dim
-                                        << ">::count() not implemented yet!");
-  return -1;
-}
-
 template< int codim, int dim, class GridImp>
-Dune::GeometryType Dune::UGGridEntity<codim,dim,GridImp>::type() const
+GeometryType UGGridEntity<codim,dim,GridImp>::type() const
 {
   static_assert(codim!=0, "The code for codim==0 is in the corresponding class specialization");
 
   // Vertex
   if (dim-codim == 0)
-    return GeometryType(0);
+    return GeometryTypes::vertex;
 
   // Edge
   if (dim-codim == 1)
-    return GeometryType(1);
+    return GeometryTypes::line;
 
   // Face in 3d
   switch (UG_NS<dim>::Tag(target_)) {
   case UG::D2::TRIANGLE :
-    return GeometryType(GeometryType::simplex,2);
+    return GeometryTypes::triangle;
   case UG::D2::QUADRILATERAL :
-    return GeometryType(GeometryType::cube,2);
+    return GeometryTypes::quadrilateral;
   default :
     DUNE_THROW(GridError, "UGGridGeometry::type():  ERROR:  Unknown type "
                << UG_NS<dim>::Tag(target_) << " found!");
@@ -65,13 +56,13 @@ Dune::GeometryType Dune::UGGridEntity<codim,dim,GridImp>::type() const
 ////////////////////////////////////////////////////////////////////////////
 
 template< int dim, class GridImp>
-bool Dune::UGGridEntity < 0, dim ,GridImp >::isNew () const
+bool UGGridEntity < 0, dim ,GridImp >::isNew () const
 {
   return UG_NS<dim>::ReadCW(target_, UG_NS<dim>::NEWEL_CE);
 }
 
 template< int dim, class GridImp>
-bool Dune::UGGridEntity < 0, dim ,GridImp >::mightVanish () const
+bool UGGridEntity < 0, dim ,GridImp >::mightVanish () const
 {
   if ((!isRegular()) || (UG_NS<dim>::ReadCW(target_, UG_NS<dim>::COARSEN_CE)))
     return true;
@@ -84,7 +75,7 @@ bool Dune::UGGridEntity < 0, dim ,GridImp >::mightVanish () const
     UG_NS<dim>::GetSons(father_,sons_);
     for (int i = 0; i < UG_NS<dim>::MAX_SONS; ++i)
     {
-      if (sons_[i] == NULL) // last son visited
+      if (sons_[i] == nullptr) // last son visited
         break;
       if (!UG_NS<dim>::isRegular(sons_[i]) || UG_NS<dim>::ReadCW(sons_[i], UG_NS<dim>::COARSEN_CE))
         return true;
@@ -95,50 +86,12 @@ bool Dune::UGGridEntity < 0, dim ,GridImp >::mightVanish () const
   return false;
 }
 
-//*****************************************************************8
-// count
-template <int dim, class GridImp>
-template <int cc>
-int Dune::UGGridEntity<0,dim,GridImp>::count() const
-{
-  if (dim==3) {
-
-    switch (cc) {
-    case 0 :
-      return 1;
-    case 1 :
-      return UG_NS<dim>::Sides_Of_Elem(target_);
-    case 2 :
-      return UG_NS<dim>::Edges_Of_Elem(target_);
-    case 3 :
-      return UG_NS<dim>::Corners_Of_Elem(target_);
-    }
-
-  } else {
-
-    switch (cc) {
-    case 0 :
-      return 1;
-    case 1 :
-      return UG_NS<dim>::Edges_Of_Elem(target_);
-    case 2 :
-      return UG_NS<dim>::Corners_Of_Elem(target_);
-    default :
-      // do nothing for cc = 3
-      break;
-    }
-
-  }
-  DUNE_THROW(GridError, "You can't call UGGridEntity<0,dim>::count<codim> "
-             << "with dim==" << dim << " and codim==" << cc << "!");
-}
-
 template <int dim, class GridImp>
 template <int cc>
 typename GridImp::template Codim<cc>::Entity
-Dune::UGGridEntity<0,dim,GridImp>::subEntity ( int i ) const
+UGGridEntity<0,dim,GridImp>::subEntity ( int i ) const
 {
-  assert(i>=0 && i<count<cc>());
+  assert(i>=0 && i < subEntities(cc));
 
   typename UG_NS<dim>::template Entity<cc>::T* subEntity;
 
@@ -153,19 +106,19 @@ Dune::UGGridEntity<0,dim,GridImp>::subEntity ( int i ) const
   else
     DUNE_THROW(GridError, "subEntity for nonexisting codimension requested!" );
 
-  return typename GridImp::template Codim<cc>::Entity(Dune::UGGridEntity<cc,dim,GridImp>((typename UG_NS<dim>::template Entity<cc>::T*)subEntity, gridImp_));
+  return typename GridImp::template Codim<cc>::Entity(UGGridEntity<cc,dim,GridImp>((typename UG_NS<dim>::template Entity<cc>::T*)subEntity, gridImp_));
 }
 
 template<int dim, class GridImp>
-Dune::GeometryType Dune::UGGridEntity<0,dim,GridImp>::type() const
+GeometryType UGGridEntity<0,dim,GridImp>::type() const
 {
   if (dim==2) {
 
     switch (UG_NS<dim>::Tag(target_)) {
     case UG::D2::TRIANGLE :
-      return GeometryType(GeometryType::simplex,2);
+      return GeometryTypes::triangle;
     case UG::D2::QUADRILATERAL :
-      return GeometryType(GeometryType::cube,2);
+      return GeometryTypes::quadrilateral;
     default :
       DUNE_THROW(GridError, "UGGridGeometry::type():  ERROR:  Unknown type "
                  << UG_NS<dim>::Tag(target_) << " found!");
@@ -176,13 +129,13 @@ Dune::GeometryType Dune::UGGridEntity<0,dim,GridImp>::type() const
     switch (UG_NS<dim>::Tag(target_)) {
 
     case UG::D3::TETRAHEDRON :
-      return GeometryType(GeometryType::simplex,3);
+      return GeometryTypes::tetrahedron;
     case UG::D3::PYRAMID :
-      return GeometryType(GeometryType::pyramid,3);
+      return GeometryTypes::pyramid;
     case UG::D3::PRISM :
-      return GeometryType(GeometryType::prism,3);
+      return GeometryTypes::prism;
     case UG::D3::HEXAHEDRON :
-      return GeometryType(GeometryType::cube,3);
+      return GeometryTypes::hexahedron;
     default :
       DUNE_THROW(GridError, "UGGridGeometry::type():  ERROR:  Unknown type "
                  << UG_NS<dim>::Tag(target_) << " found!");
@@ -195,7 +148,7 @@ Dune::GeometryType Dune::UGGridEntity<0,dim,GridImp>::type() const
 
 
 template<int dim, class GridImp>
-void Dune::UGGridEntity < 0, dim ,GridImp >::
+void UGGridEntity < 0, dim ,GridImp >::
 setToTarget(typename UG_NS<dim>::Element* target, const GridImp* gridImp)
 {
   target_ = target;
@@ -204,8 +157,8 @@ setToTarget(typename UG_NS<dim>::Element* target, const GridImp* gridImp)
 }
 
 template<int dim, class GridImp>
-Dune::UGGridHierarchicIterator<GridImp>
-Dune::UGGridEntity < 0, dim ,GridImp >::hbegin(int maxlevel) const
+UGGridHierarchicIterator<GridImp>
+UGGridEntity < 0, dim ,GridImp >::hbegin(int maxlevel) const
 {
   UGGridHierarchicIterator<GridImp> it(maxlevel,gridImp_);
 
@@ -218,8 +171,8 @@ Dune::UGGridEntity < 0, dim ,GridImp >::hbegin(int maxlevel) const
     for (int i=0; i<UG_NS<dim>::nSons(target_); i++)
       it.elementStack_.push(sonList[i]);
 
-    it.virtualEntity_.setToTarget( (it.elementStack_.empty())
-                                   ? NULL
+    it.virtualEntity_.setToTarget( it.elementStack_.empty()
+                                   ? nullptr
                                    : it.elementStack_.top(),
                                    gridImp_
                                    );
@@ -233,15 +186,16 @@ Dune::UGGridEntity < 0, dim ,GridImp >::hbegin(int maxlevel) const
 
 
 template< int dim, class GridImp>
-Dune::UGGridHierarchicIterator<GridImp>
-Dune::UGGridEntity < 0, dim ,GridImp >::hend(int maxlevel) const
+UGGridHierarchicIterator<GridImp>
+UGGridEntity < 0, dim ,GridImp >::hend(int maxlevel) const
 {
   return UGGridHierarchicIterator<GridImp>(maxlevel,gridImp_);
 }
 
 template<int dim, class GridImp>
-typename Dune::UGGridEntity<0,dim,GridImp>::LocalGeometry
-Dune::UGGridEntity < 0, dim, GridImp>::geometryInFather () const
+auto
+UGGridEntity < 0, dim, GridImp>::geometryInFather () const
+  -> LocalGeometry
 {
   // we need to have a father element
   typename UG_NS<dim>::Element* fatherElement = UG_NS<dim>::EFather(target_);
@@ -421,42 +375,34 @@ Dune::UGGridEntity < 0, dim, GridImp>::geometryInFather () const
   return LocalGeometry(LocalGeometryImpl(type(), cornerCoordinates));
 }
 
-template class Dune::UGGridEntity<2,2, const Dune::UGGrid<2> >;
-template class Dune::UGGridEntity<3,3, const Dune::UGGrid<3> >;
+template class UGGridEntity<2,2, const UGGrid<2> >;
+template class UGGridEntity<3,3, const UGGrid<3> >;
 
-template class Dune::UGGridEntity<0,2, const Dune::UGGrid<2> >;
-template class Dune::UGGridEntity<0,3, const Dune::UGGrid<3> >;
+template class UGGridEntity<0,2, const UGGrid<2> >;
+template class UGGridEntity<0,3, const UGGrid<3> >;
 
-template class Dune::UGGridEntity<1,2, const Dune::UGGrid<2> >;
-template class Dune::UGGridEntity<2,3, const Dune::UGGrid<3> >;
+template class UGGridEntity<1,2, const UGGrid<2> >;
+template class UGGridEntity<2,3, const UGGrid<3> >;
 
-template int Dune::UGGridEntity<0, 2, const Dune::UGGrid<2> >::count<0>() const;
-template int Dune::UGGridEntity<0, 2, const Dune::UGGrid<2> >::count<1>() const;
-template int Dune::UGGridEntity<0, 2, const Dune::UGGrid<2> >::count<2>() const;
+template Grid<2, 2, double, UGGridFamily<2> >::Codim<0>::Entity
+UGGridEntity<0, 2, const UGGrid<2> >::subEntity<0>(int) const;
 
-template int Dune::UGGridEntity<0, 3, const Dune::UGGrid<3> >::count<0>() const;
-template int Dune::UGGridEntity<0, 3, const Dune::UGGrid<3> >::count<1>() const;
-template int Dune::UGGridEntity<0, 3, const Dune::UGGrid<3> >::count<2>() const;
-template int Dune::UGGridEntity<0, 3, const Dune::UGGrid<3> >::count<3>() const;
+template Grid<2, 2, double, UGGridFamily<2> >::Codim<1>::Entity
+UGGridEntity<0, 2, const UGGrid<2> >::subEntity<1>(int) const;
 
+template Grid<2, 2, double, UGGridFamily<2> >::Codim<2>::Entity
+UGGridEntity<0, 2, const UGGrid<2> >::subEntity<2>(int) const;
 
-template Dune::Grid<2, 2, double, Dune::UGGridFamily<2> >::Codim<0>::Entity
-Dune::UGGridEntity<0, 2, const Dune::UGGrid<2> >::subEntity<0>(int) const;
+template Grid<3, 3, double, UGGridFamily<3> >::Codim<0>::Entity
+UGGridEntity<0, 3, const UGGrid<3> >::subEntity<0>(int) const;
 
-template Dune::Grid<2, 2, double, Dune::UGGridFamily<2> >::Codim<1>::Entity
-Dune::UGGridEntity<0, 2, const Dune::UGGrid<2> >::subEntity<1>(int) const;
+template Grid<3, 3, double, UGGridFamily<3> >::Codim<1>::Entity
+UGGridEntity<0, 3, const UGGrid<3> >::subEntity<1>(int) const;
 
-template Dune::Grid<2, 2, double, Dune::UGGridFamily<2> >::Codim<2>::Entity
-Dune::UGGridEntity<0, 2, const Dune::UGGrid<2> >::subEntity<2>(int) const;
+template Grid<3, 3, double, UGGridFamily<3> >::Codim<2>::Entity
+UGGridEntity<0, 3, const UGGrid<3> >::subEntity<2>(int) const;
 
-template Dune::Grid<3, 3, double, Dune::UGGridFamily<3> >::Codim<0>::Entity
-Dune::UGGridEntity<0, 3, const Dune::UGGrid<3> >::subEntity<0>(int) const;
+template Grid<3, 3, double, UGGridFamily<3> >::Codim<3>::Entity
+UGGridEntity<0, 3, const UGGrid<3> >::subEntity<3>(int) const;
 
-template Dune::Grid<3, 3, double, Dune::UGGridFamily<3> >::Codim<1>::Entity
-Dune::UGGridEntity<0, 3, const Dune::UGGrid<3> >::subEntity<1>(int) const;
-
-template Dune::Grid<3, 3, double, Dune::UGGridFamily<3> >::Codim<2>::Entity
-Dune::UGGridEntity<0, 3, const Dune::UGGrid<3> >::subEntity<2>(int) const;
-
-template Dune::Grid<3, 3, double, Dune::UGGridFamily<3> >::Codim<3>::Entity
-Dune::UGGridEntity<0, 3, const Dune::UGGrid<3> >::subEntity<3>(int) const;
+} /* namespace Dune */
